==> phpBB-3.0.2_to_3.0.8-RC1.tar.bz2: install/update/index.php <==
<?php

if (!defined('IN_PHPBB'))
{
	exit;
}

// Set update info with file structure to update
$update_info = array(
	'version'	=> array('from' => '3.0.2', 'to' => '3.0.8-RC1'),
'files'		=> array('adm/index.php',
	'adm/style/acp_ban.html',
	'adm/style/acp_captcha.html',
	'adm/style/acp_database.html',
	'adm/style/acp_email.html',
	'adm/style/acp_forums_copy_perm.html',
	'adm/style/acp_forums.html',
	'adm/style/acp_groups.html',
	'adm/style/acp_icons.html',
	'adm/style/acp_inactive.html',
	'adm/style/acp_jabber.html',
	'adm/style/acp_logs.html',
	'adm/style/acp_main.html',
	'adm/style/acp_permissions.html',
	'adm/style/acp_profile.html',
	'adm/style/acp_search.html',
	'adm/style/acp_send_statistics.html',
	'adm/style/acp_styles.html',
	'adm/style/acp_update.html',
	'adm/style/acp_users_avatar.html',
	'adm/style/acp_users.html',
	'adm/style/acp_users_overview.html',
	'adm/style/acp_users_signature.html',
	'adm/style/acp_users_warnings.html',
	'adm/style/admin.css',
	'adm/style/captcha_default_acp_demo.html',
	'adm/style/captcha_gd_acp.html',
	'adm/style/captcha_qa_acp_demo.html',
	'adm/style/captcha_qa_acp.html',
	'adm/style/captcha_recaptcha_acp.html',
	'adm/style/captcha_recaptcha.html',
	'adm/style/confirm_bbcode.html',
	'adm/style/editor.js',
	'adm/style/install_footer.html',
	'adm/style/install_update_diff.html',
	'adm/style/install_update.html',
	'adm/style/overall_footer.html',
	'adm/style/overall_header.html',
	'adm/style/permission_forum_copy.html',
	'adm/style/permission_mask.html',
	'adm/style/simple_header.html',
	'common.php',
	'download/file.php',
	'faq.php',
	'feed.php',
	'.htaccess',
	'includes/acm/acm_apc.php',
	'includes/acm/acm_eaccelerator.php',
	'includes/acm/acm_file.php',
	'includes/acm/acm_memcache.php',
	'includes/acm/acm_memory.php',
	'includes/acm/acm_null.php',
	'includes/acm/acm_xcache.php',
	'includes/acp/acp_attachments.php',
	'includes/acp/acp_ban.php',
	'includes/acp/acp_bbcodes.php',
	'includes/acp/acp_board.php',
	'includes/acp/acp_captcha.php',
	'includes/acp/acp_database.php',
	'includes/acp/acp_email.php',
	'includes/acp/acp_forums.php',
	'includes/acp/acp_groups.php',
	'includes/acp/acp_icons.php',
	'includes/acp/acp_inactive.php',
	'includes/acp/acp_jabber.php',
	'includes/acp/acp_language.php',
	'includes/acp/acp_logs.php',
	'includes/acp/acp_main.php',
	'includes/acp/acp_modules.php',
	'includes/acp/acp_permissions.php',
	'includes/acp/acp_php_info.php',
	'includes/acp/acp_profile.php',
	'includes/acp/acp_prune.php',
	'includes/acp/acp_ranks.php',
	'includes/acp/acp_reasons.php',
	'includes/acp/acp_search.php',
	'includes/acp/acp_send_statistics.php',
	'includes/acp/acp_styles.php',
	'includes/acp/acp_update.php',
	'includes/acp/acp_users.php',
	'includes/acp/acp_words.php',
	'includes/acp/auth.php',
	'includes/acp/info/acp_board.php',
	'includes/acp/info/acp_email.php',
	'includes/acp/info/acp_permissions.php',
	'includes/acp/info/acp_send_statistics.php',
	'includes/acp/info/acp_users.php',
	'includes/auth/auth_apache.php',
	'includes/auth/auth_db.php',
	'includes/auth/auth_ldap.php',
	'includes/auth.php',
	'includes/bbcode.php',
	'includes/cache.php',
	'includes/captcha/captcha_factory.php',
	'includes/captcha/captcha_gd.php',
	'includes/captcha/captcha_gd_wave.php',
	'includes/captcha/plugins/captcha_abstract.php',
	'includes/captcha/plugins/phpbb_captcha_gd_plugin.php',
	'includes/captcha/plugins/phpbb_captcha_gd_wave_plugin.php',
	'includes/captcha/plugins/phpbb_captcha_nogd_plugin.php',
	'includes/captcha/plugins/phpbb_captcha_qa_plugin.php',
	'includes/captcha/plugins/phpbb_recaptcha_plugin.php',
	'includes/constants.php',
	'includes/db/dbal.php',
	'includes/db/db_tools.php',
	'includes/db/firebird.php',
	'includes/db/mssqlnative.php',
	'includes/db/mssql_odbc.php',
	'includes/db/mssql.php',
	'includes/db/mysqli.php',
	'includes/db/mysql.php',
	'includes/db/oracle.php',
	'includes/db/postgres.php',
	'includes/db/sqlite.php',
	'includes/diff/diff.php',
	'includes/diff/engine.php',
	'includes/diff/renderer.php',
	'includes/functions_admin.php',
	'includes/functions_compress.php',
	'includes/functions_content.php',
	'includes/functions_convert.php',
	'includes/functions_display.php',
	'includes/functions_install.php',
	'includes/functions_jabber.php',
	'includes/functions_messenger.php',
	'includes/functions_module.php',
	'includes/functions.php',
	'includes/functions_posting.php',
	'includes/functions_privmsgs.php',
	'includes/functions_profile_fields.php',
	'includes/functions_template.php',
	'includes/functions_transfer.php',
	'includes/functions_upload.php',
	'includes/functions_user.php',
	'includes/.htaccess',
	'includes/mcp/info/mcp_pm_reports.php',
	'includes/mcp/mcp_forum.php',
	'includes/mcp/mcp_front.php',
	'includes/mcp/mcp_logs.php',
	'includes/mcp/mcp_main.php',
	'includes/mcp/mcp_notes.php',
	'includes/mcp/mcp_pm_reports.php',
	'includes/mcp/mcp_post.php',
	'includes/mcp/mcp_queue.php',
	'includes/mcp/mcp_reports.php',
	'includes/mcp/mcp_topic.php',
	'includes/mcp/mcp_warn.php',
	'includes/message_parser.php',
	'includes/questionnaire/questionnaire.php',
	'includes/search/fulltext_mysql.php',
	'includes/search/fulltext_native.php',
	'includes/search/search.php',
	'includes/session.php',
	'includes/template.php',
	'includes/ucp/info/ucp_profile.php',
	'includes/ucp/ucp_activate.php',
	'includes/ucp/ucp_attachments.php',
	'includes/ucp/ucp_confirm.php',
	'includes/ucp/ucp_groups.php',
	'includes/ucp/ucp_main.php',
	'includes/ucp/ucp_pm_compose.php',
	'includes/ucp/ucp_pm_options.php',
	'includes/ucp/ucp_pm.php',
	'includes/ucp/ucp_pm_viewfolder.php',
	'includes/ucp/ucp_pm_viewmessage.php',
	'includes/ucp/ucp_prefs.php',
	'includes/ucp/ucp_profile.php',
	'includes/ucp/ucp_register.php',
	'includes/ucp/ucp_remind.php',
	'includes/ucp/ucp_resend.php',
	'includes/ucp/ucp_zebra.php',
	'includes/utf/utf_tools.php',
	'index.php',
	'language/en/acp/attachments.php',
	'language/en/acp/ban.php',
	'language/en/acp/board.php',
	'language/en/acp/common.php',
	'language/en/acp/database.php',
	'language/en/acp/forums.php',
	'language/en/acp/groups.php',
	'language/en/acp/language.php',
	'language/en/acp/permissions.php',
	'language/en/acp/permissions_phpbb.php',
	'language/en/acp/posting.php',
	'language/en/acp/profile.php',
	'language/en/acp/prune.php',
	'language/en/acp/search.php',
	'language/en/acp/styles.php',
	'language/en/acp/users.php',
	'language/en/captcha_qa.php',
	'language/en/captcha_recaptcha.php',
	'language/en/common.php',
	'language/en/email/admin_welcome_activated.txt',
	'language/en/email/admin_welcome_inactive.txt',
	'language/en/email/coppa_resend_inactive.txt',
	'language/en/email/coppa_welcome_inactive.txt',
	'language/en/email/group_request.txt',
	'language/en/email/installed.txt',
	'language/en/email/newtopic_notify.txt',
	'language/en/email/pm_report_closed.txt',
	'language/en/email/pm_report_deleted.txt',
	'language/en/email/user_reactivate_account.txt',
	'language/en/email/user_remind_inactive.txt',
	'language/en/email/user_resend_inactive.txt',
	'language/en/email/user_welcome_inactive.txt',
	'language/en/email/user_welcome.txt',
	'language/en/help_bbcode.php',
	'language/en/help_faq.php',
	'language/en/install.php',
	'language/en/mcp.php',
	'language/en/memberlist.php',
	'language/en/posting.php',
	'language/en/search.php',
	'language/en/search_synonyms.php',
	'language/en/ucp.php',
	'language/en/viewforum.php',
	'language/en/viewtopic.php',
	'mcp.php',
	'memberlist.php',
	'posting.php',
	'report.php',
	'search.php',
	'style.php',
	'styles/prosilver/imageset/imageset.cfg',
	'styles/prosilver/style.cfg',
	'styles/prosilver/template/attachment.html',
	'styles/prosilver/template/captcha_default.html',
	'styles/prosilver/template/captcha_qa.html',
	'styles/prosilver/template/captcha_recaptcha.html',
	'styles/prosilver/template/drafts.html',
	'styles/prosilver/template/editor.js',
	'styles/prosilver/template/faq_body.html',
	'styles/prosilver/template/forum_fn.js',
	'styles/prosilver/template/forumlist_body.html',
	'styles/prosilver/template/index_body.html',
	'styles/prosilver/template/login_body.html',
	'styles/prosilver/template/login_forum.html',
	'styles/prosilver/template/mcp_forum.html',
	'styles/prosilver/template/mcp_front.html',
	'styles/prosilver/template/mcp_header.html',
	'styles/prosilver/template/mcp_logs.html',
	'styles/prosilver/template/mcp_notes_user.html',
	'styles/prosilver/template/mcp_post.html',
	'styles/prosilver/template/mcp_queue.html',
	'styles/prosilver/template/mcp_reports.html',
	'styles/prosilver/template/mcp_topic.html',
	'styles/prosilver/template/mcp_warn_post.html',
	'styles/prosilver/template/mcp_warn_user.html',
	'styles/prosilver/template/memberlist_body.html',
	'styles/prosilver/template/memberlist_im.html',
	'styles/prosilver/template/memberlist_leaders.html',
	'styles/prosilver/template/memberlist_search.html',
	'styles/prosilver/template/memberlist_view.html',
	'styles/prosilver/template/overall_footer.html',
	'styles/prosilver/template/overall_header.html',
	'styles/prosilver/template/posting_buttons.html',
	'styles/prosilver/template/posting_editor.html',
	'styles/prosilver/template/posting_preview.html',
	'styles/prosilver/template/posting_review.html',
	'styles/prosilver/template/posting_smilies.html',
	'styles/prosilver/template/posting_topic_review.html',
	'styles/prosilver/template/quickreply_editor.html',
	'styles/prosilver/template/search_body.html',
	'styles/prosilver/template/search_results.html',
	'styles/prosilver/template/simple_header.html',
	'styles/prosilver/template/styleswitcher.js',
	'styles/prosilver/template/template.cfg',
	'styles/prosilver/template/ucp_agreement.html',
	'styles/prosilver/template/ucp_avatar_options.html',
	'styles/prosilver/template/ucp_groups_manage.html',
	'styles/prosilver/template/ucp_main_bookmarks.html',
	'styles/prosilver/template/ucp_main_front.html',
	'styles/prosilver/template/ucp_main_subscribed.html',
	'styles/prosilver/template/ucp_pm_history.html',
	'styles/prosilver/template/ucp_pm_message_header.html',
	'styles/prosilver/template/ucp_pm_viewfolder.html',
	'styles/prosilver/template/ucp_pm_viewmessage.html',
	'styles/prosilver/template/ucp_pm_viewmessage_print.html',
	'styles/prosilver/template/ucp_profile_signature.html',
	'styles/prosilver/template/ucp_register.html',
	'styles/prosilver/template/viewforum_body.html',
	'styles/prosilver/template/viewtopic_body.html',
	'styles/prosilver/template/viewtopic_print.html',
	'styles/prosilver/theme/bidi.css',
	'styles/prosilver/theme/colours.css',
	'styles/prosilver/theme/common.css',
	'styles/prosilver/theme/content.css',
	'styles/prosilver/theme/cp.css',
	'styles/prosilver/theme/forms.css',
	'styles/prosilver/theme/links.css',
	'styles/prosilver/theme/print.css',
	'styles/prosilver/theme/theme.cfg',
	'styles/prosilver/theme/tweaks.css',
	'styles/subsilver2/imageset/imageset.cfg',
	'styles/subsilver2/style.cfg',
	'styles/subsilver2/template/attachment.html',
	'styles/subsilver2/template/captcha_default.html',
	'styles/subsilver2/template/captcha_qa.html',
	'styles/subsilver2/template/captcha_recaptcha.html',
	'styles/subsilver2/template/editor.js',
	'styles/subsilver2/template/faq_body.html',
	'styles/subsilver2/template/forumlist_body.html',
	'styles/subsilver2/template/index_body.html',
	'styles/subsilver2/template/login_body.html',
	'styles/subsilver2/template/login_forum.html',
	'styles/subsilver2/template/mcp_ban.html',
	'styles/subsilver2/template/mcp_forum.html',
	'styles/subsilver2/template/mcp_front.html',
	'styles/subsilver2/template/mcp_logs.html',
	'styles/subsilver2/template/mcp_notes_user.html',
	'styles/subsilver2/template/mcp_post.html',
	'styles/subsilver2/template/mcp_reports.html',
	'styles/subsilver2/template/mcp_topic.html',
	'styles/subsilver2/template/mcp_warn_post.html',
	'styles/subsilver2/template/mcp_warn_user.html',
	'styles/subsilver2/template/memberlist_im.html',
	'styles/subsilver2/template/memberlist_view.html',
	'styles/subsilver2/template/overall_header.html',
	'styles/subsilver2/template/posting_body.html',
	'styles/subsilver2/template/posting_buttons.html',
	'styles/subsilver2/template/posting_review.html',
	'styles/subsilver2/template/posting_smilies.html',
	'styles/subsilver2/template/posting_topic_review.html',
	'styles/subsilver2/template/quickreply_editor.html',
	'styles/subsilver2/template/report_body.html',
	'styles/subsilver2/template/search_body.html',
	'styles/subsilver2/template/search_results.html',
	'styles/subsilver2/template/template.cfg',
	'styles/subsilver2/template/ucp_agreement.html',
	'styles/subsilver2/template/ucp_groups_manage.html',
	'styles/subsilver2/template/ucp_header.html',
	'styles/subsilver2/template/ucp_main_drafts.html',
	'styles/subsilver2/template/ucp_main_front.html',
	'styles/subsilver2/template/ucp_main_subscribed.html',
	'styles/subsilver2/template/ucp_pm_history.html',
	'styles/subsilver2/template/ucp_pm_message_footer.html',
	'styles/subsilver2/template/ucp_pm_viewfolder.html',
	'styles/subsilver2/template/ucp_pm_viewmessage.html',
	'styles/subsilver2/template/ucp_pm_viewmessage_print.html',
	'styles/subsilver2/template/ucp_profile_avatar.html',
	'styles/subsilver2/template/ucp_profile_signature.html',
	'styles/subsilver2/template/ucp_register.html',
	'styles/subsilver2/template/ucp_zebra_foes.html',
	'styles/subsilver2/template/viewforum_body.html',
	'styles/subsilver2/template/viewtopic_body.html',
	'styles/subsilver2/template/viewtopic_print.html',
	'styles/subsilver2/theme/stylesheet.css',
	'styles/subsilver2/theme/theme.cfg',
	'ucp.php',
	'viewforum.php',
	'viewonline.php',
	'viewtopic.php',
	'web.config'),
'binary'		=> array(),
);

?>

==> phpBB-3.0.3_to_3.0.9-RC1.tar.bz2: install/update/index.php <==
<?php

if (!defined('IN_PHPBB'))
{
	exit;
}

// Set update info with file structure to update
$update_info = array(
	'version'	=> array('from' => '3.0.3', 'to' => '3.0.9-RC1'),
'files'		=> array('adm/index.php',
	'adm/style/acp_ban.html',
	'adm/style/acp_captcha.html',
	'adm/style/acp_database.html',
	'adm/style/acp_email.html',
	'adm/style/acp_forums_copy_perm.html',
	'adm/style/acp_forums.html',
	'adm/style/acp_groups.html',
	'adm/style/acp_icons.html',
	'adm/style/acp_inactive.html',
	'adm/style/acp_jabber.html',
	'adm/style/acp_logs.html',
	'adm/style/acp_main.html',
	'adm/style/acp_permissions.html',
	'adm/style/acp_profile.html',
	'adm/style/acp_ranks.html',
	'adm/style/acp_search.html',
	'adm/style/acp_send_statistics.html',
	'adm/style/acp_styles.html',
	'adm/style/acp_update.html',
	'adm/style/acp_users_avatar.html',
	'adm/style/acp_users.html',
	'adm/style/acp_users_overview.html',
	'adm/style/acp_users_signature.html',
	'adm/style/acp_users_warnings.html',
	'adm/style/admin.css',
	'adm/style/captcha_default_acp_demo.html',
	'adm/style/captcha_gd_acp.html',
	'adm/style/captcha_qa_acp_demo.html',
	'adm/style/captcha_qa_acp.html',
	'adm/style/captcha_recaptcha_acp.html',
	'adm/style/captcha_recaptcha.html',
	'adm/style/confirm_bbcode.html',
	'adm/style/editor.js',
	'adm/style/install_footer.html',
	'adm/style/install_update_diff.html',
	'adm/style/install_update.html',
	'adm/style/overall_footer.html',
	'adm/style/overall_header.html',
	'adm/style/permission_forum_copy.html',
	'adm/style/permission_mask.html',
	'adm/style/simple_footer.html',
	'adm/style/simple_header.html',
	'common.php',
	'cron.php',
	'download/file.php',
	'faq.php',
	'feed.php',
	'.htaccess',
	'includes/acm/acm_apc.php',
	'includes/acm/acm_eaccelerator.php',
	'includes/acm/acm_file.php',
	'includes/acm/acm_memcache.php',
	'includes/acm/acm_memory.php',
	'includes/acm/acm_null.php',
	'includes/acm/acm_redis.php',
	'includes/acm/acm_wincache.php',
	'includes/acm/acm_xcache.php',
	'includes/acp/acp_attachments.php',
	'includes/acp/acp_ban.php',
	'includes/acp/acp_bbcodes.php',
	'includes/acp/acp_board.php',
	'includes/acp/acp_captcha.php',
	'includes/acp/acp_database.php',
	'includes/acp/acp_disallow.php',
	'includes/acp/acp_email.php',
	'includes/acp/acp_forums.php',
	'includes/acp/acp_groups.php',
	'includes/acp/acp_icons.php',
	'includes/acp/acp_inactive.php',
	'includes/acp/acp_jabber.php',
	'includes/acp/acp_language.php',
	'includes/acp/acp_logs.php',
	'includes/acp/acp_main.php',
	'includes/acp/acp_modules.php',
	'includes/acp/acp_permissions.php',
	'includes/acp/acp_php_info.php',
	'includes/acp/acp_profile.php',
	'includes/acp/acp_prune.php',
	'includes/acp/acp_ranks.php',
	'includes/acp/acp_reasons.php',
	'includes/acp/acp_search.php',
	'includes/acp/acp_send_statistics.php',
	'includes/acp/acp_styles.php',
	'includes/acp/acp_update.php',
	'includes/acp/acp_users.php',
	'includes/acp/acp_words.php',
	'includes/acp/auth.php',
	'includes/acp/info/acp_board.php',
	'includes/acp/info/acp_permissions.php',
	'includes/acp/info/acp_send_statistics.php',
	'includes/acp/info/acp_users.php',
	'includes/auth/auth_apache.php',
	'includes/auth/auth_db.php',
	'includes/auth/auth_ldap.php',
	'includes/auth.php',
	'includes/bbcode.php',
	'includes/cache.php',
	'includes/captcha/captcha_factory.php',
	'includes/captcha/captcha_gd.php',
	'includes/captcha/captcha_gd_wave.php',
	'includes/captcha/plugins/captcha_abstract.php',
	'includes/captcha/plugins/phpbb_captcha_gd_plugin.php',
	'includes/captcha/plugins/phpbb_captcha_gd_wave_plugin.php',
	'includes/captcha/plugins/phpbb_captcha_nogd_plugin.php',
	'includes/captcha/plugins/phpbb_captcha_qa_plugin.php',
	'includes/captcha/plugins/phpbb_recaptcha_plugin.php',
	'includes/constants.php',
	'includes/db/dbal.php',
	'includes/db/db_tools.php',
	'includes/db/firebird.php',
	'includes/db/mssqlnative.php',
	'includes/db/mssql_odbc.php',
	'includes/db/mssql.php',
	'includes/db/mysqli.php',
	'includes/db/mysql.php',
	'includes/db/oracle.php',
	'includes/db/postgres.php',
	'includes/db/sqlite.php',
	'includes/diff/diff.php',
	'includes/diff/engine.php',
	'includes/diff/renderer.php',
	'includes/error_collector.php',
	'includes/functions_admin.php',
	'includes/functions_compress.php',
	'includes/functions_content.php',
	'includes/functions_convert.php',
	'includes/functions_display.php',
	'includes/functions_install.php',
	'includes/functions_jabber.php',
	'includes/functions_messenger.php',
	'includes/functions_module.php',
	'includes/functions.php',
	'includes/functions_posting.php',
	'includes/functions_privmsgs.php',
	'includes/functions_profile_fields.php',
	'includes/functions_template.php',
	'includes/functions_transfer.php',
	'includes/functions_upload.php',
	'includes/functions_user.php',
	'includes/.htaccess',
	'includes/mcp/info/mcp_pm_reports.php',
	'includes/mcp/mcp_front.php',
	'includes/mcp/mcp_logs.php',
	'includes/mcp/mcp_main.php',
	'includes/mcp/mcp_notes.php',
	'includes/mcp/mcp_pm_reports.php',
	'includes/mcp/mcp_post.php',
	'includes/mcp/mcp_queue.php',
	'includes/mcp/mcp_reports.php',
	'includes/mcp/mcp_topic.php',
	'includes/mcp/mcp_warn.php',
	'includes/message_parser.php',
	'includes/questionnaire/questionnaire.php',
	'includes/search/fulltext_mysql.php',
	'includes/search/fulltext_native.php',
	'includes/session.php',
	'includes/template.php',
	'includes/ucp/info/ucp_profile.php',
	'includes/ucp/ucp_activate.php',
	'includes/ucp/ucp_attachments.php',
	'includes/ucp/ucp_confirm.php',
	'includes/ucp/ucp_groups.php',
	'includes/ucp/ucp_main.php',
	'includes/ucp/ucp_pm_compose.php',
	'includes/ucp/ucp_pm_options.php',
	'includes/ucp/ucp_pm.php',
	'includes/ucp/ucp_pm_viewfolder.php',
	'includes/ucp/ucp_pm_viewmessage.php',
	'includes/ucp/ucp_prefs.php',
	'includes/ucp/ucp_profile.php',
	'includes/ucp/ucp_register.php',
	'includes/ucp/ucp_remind.php',
	'includes/ucp/ucp_resend.php',
	'includes/ucp/ucp_zebra.php',
	'includes/utf/utf_tools.php',
	'index.php',
	'language/en/acp/attachments.php',
	'language/en/acp/ban.php',
	'language/en/acp/board.php',
	'language/en/acp/common.php',
	'language/en/acp/database.php',
	'language/en/acp/email.php',
	'language/en/acp/forums.php',
	'language/en/acp/groups.php',
	'language/en/acp/language.php',
	'language/en/acp/permissions.php',
	'language/en/acp/permissions_phpbb.php',
	'language/en/acp/posting.php',
	'language/en/acp/profile.php',
	'language/en/acp/prune.php',
	'language/en/acp/search.php',
	'language/en/acp/styles.php',
	'language/en/acp/users.php',
	'language/en/captcha_qa.php',
	'language/en/captcha_recaptcha.php',
	'language/en/common.php',
	'language/en/email/admin_welcome_activated.txt',
	'language/en/email/admin_welcome_inactive.txt',
	'language/en/email/coppa_resend_inactive.txt',
	'language/en/email/coppa_welcome_inactive.txt',
	'language/en/email/installed.txt',
	'language/en/email/newtopic_notify.txt',
	'language/en/email/pm_report_closed.txt',
	'language/en/email/pm_report_deleted.txt',
	'language/en/email/user_reactivate_account.txt',
	'language/en/email/user_remind_inactive.txt',
	'language/en/email/user_resend_inactive.txt',
	'language/en/email/user_welcome_inactive.txt',
	'language/en/email/user_welcome.txt',
	'language/en/help_bbcode.php',
	'language/en/help_faq.php',
	'language/en/install.php',
	'language/en/mcp.php',
	'language/en/memberlist.php',
	'language/en/posting.php',
	'language/en/search.php',
	'language/en/search_synonyms.php',
	'language/en/ucp.php',
	'language/en/viewforum.php',
	'language/en/viewtopic.php',
	'mcp.php',
	'memberlist.php',
	'posting.php',
	'report.php',
	'search.php',
	'style.php',
	'styles/prosilver/imageset/imageset.cfg',
	'styles/prosilver/style.cfg',
	'styles/prosilver/template/attachment.html',
	'styles/prosilver/template/captcha_default.html',
	'styles/prosilver/template/captcha_qa.html',
	'styles/prosilver/template/captcha_recaptcha.html',
	'styles/prosilver/template/drafts.html',
	'styles/prosilver/template/editor.js',
	'styles/prosilver/template/faq_body.html',
	'styles/prosilver/template/forum_fn.js',
	'styles/prosilver/template/forumlist_body.html',
	'styles/prosilver/template/index_body.html',
	'styles/prosilver/template/login_body.html',
	'styles/prosilver/template/login_forum.html',
	'styles/prosilver/template/mcp_forum.html',
	'styles/prosilver/template/mcp_front.html',
	'styles/prosilver/template/mcp_logs.html',
	'styles/prosilver/template/mcp_notes_user.html',
	'styles/prosilver/template/mcp_post.html',
	'styles/prosilver/template/mcp_queue.html',
	'styles/prosilver/template/mcp_reports.html',
	'styles/prosilver/template/mcp_topic.html',
	'styles/prosilver/template/mcp_warn_user.html',
	'styles/prosilver/template/memberlist_body.html',
	'styles/prosilver/template/memberlist_im.html',
	'styles/prosilver/template/memberlist_search.html',
	'styles/prosilver/template/memberlist_view.html',
	'styles/prosilver/template/overall_footer.html',
	'styles/prosilver/template/overall_header.html',
	'styles/prosilver/template/posting_buttons.html',
	'styles/prosilver/template/posting_editor.html',
	'styles/prosilver/template/posting_preview.html',
	'styles/prosilver/template/posting_review.html',
	'styles/prosilver/template/posting_smilies.html',
	'styles/prosilver/template/posting_topic_review.html',
	'styles/prosilver/template/quickreply_editor.html',
	'styles/prosilver/template/search_body.html',
	'styles/prosilver/template/search_results.html',
	'styles/prosilver/template/simple_footer.html',
	'styles/prosilver/template/simple_header.html',
	'styles/prosilver/template/styleswitcher.js',
	'styles/prosilver/template/template.cfg',
	'styles/prosilver/template/ucp_agreement.html',
	'styles/prosilver/template/ucp_avatar_options.html',
	'styles/prosilver/template/ucp_groups_manage.html',
	'styles/prosilver/template/ucp_main_bookmarks.html',
	'styles/prosilver/template/ucp_main_front.html',
	'styles/prosilver/template/ucp_main_subscribed.html',
	'styles/prosilver/template/ucp_pm_history.html',
	'styles/prosilver/template/ucp_pm_message_header.html',
	'styles/prosilver/template/ucp_pm_viewfolder.html',
	'styles/prosilver/template/ucp_pm_viewmessage.html',
	'styles/prosilver/template/ucp_pm_viewmessage_print.html',
	'styles/prosilver/template/ucp_profile_signature.html',
	'styles/prosilver/template/ucp_register.html',
	'styles/prosilver/template/viewforum_body.html',
	'styles/prosilver/template/viewtopic_body.html',
	'styles/prosilver/template/viewtopic_print.html',
	'styles/prosilver/theme/bidi.css',
	'styles/prosilver/theme/colours.css',
	'styles/prosilver/theme/common.css',
	'styles/prosilver/theme/content.css',
	'styles/prosilver/theme/cp.css',
	'styles/prosilver/theme/forms.css',
	'styles/prosilver/theme/links.css',
	'styles/prosilver/theme/print.css',
	'styles/prosilver/theme/theme.cfg',
	'styles/prosilver/theme/tweaks.css',
	'styles/subsilver2/imageset/imageset.cfg',
	'styles/subsilver2/style.cfg',
	'styles/subsilver2/template/attachment.html',
	'styles/subsilver2/template/captcha_default.html',
	'styles/subsilver2/template/captcha_qa.html',
	'styles/subsilver2/template/captcha_recaptcha.html',
	'styles/subsilver2/template/editor.js',
	'styles/subsilver2/template/forumlist_body.html',
	'styles/subsilver2/template/index_body.html',
	'styles/subsilver2/template/login_body.html',
	'styles/subsilver2/template/login_forum.html',
	'styles/subsilver2/template/mcp_ban.html',
	'styles/subsilver2/template/mcp_front.html',
	'styles/subsilver2/template/mcp_logs.html',
	'styles/subsilver2/template/mcp_notes_user.html',
	'styles/subsilver2/template/mcp_post.html',
	'styles/subsilver2/template/mcp_reports.html',
	'styles/subsilver2/template/mcp_topic.html',
	'styles/subsilver2/template/mcp_warn_user.html',
	'styles/subsilver2/template/memberlist_im.html',
	'styles/subsilver2/template/memberlist_view.html',
	'styles/subsilver2/template/overall_footer.html',
	'styles/subsilver2/template/overall_header.html',
	'styles/subsilver2/template/posting_body.html',
	'styles/subsilver2/template/posting_buttons.html',
	'styles/subsilver2/template/posting_review.html',
	'styles/subsilver2/template/posting_smilies.html',
	'styles/subsilver2/template/posting_topic_review.html',
	'styles/subsilver2/template/quickreply_editor.html',
	'styles/subsilver2/template/report_body.html',
	'styles/subsilver2/template/search_body.html',
	'styles/subsilver2/template/searchbox.html',
	'styles/subsilver2/template/search_results.html',
	'styles/subsilver2/template/simple_footer.html',
	'styles/subsilver2/template/simple_header.html',
	'styles/subsilver2/template/template.cfg',
	'styles/subsilver2/template/ucp_agreement.html',
	'styles/subsilver2/template/ucp_groups_manage.html',
	'styles/subsilver2/template/ucp_header.html',
	'styles/subsilver2/template/ucp_main_drafts.html',
	'styles/subsilver2/template/ucp_main_front.html',
	'styles/subsilver2/template/ucp_pm_history.html',
	'styles/subsilver2/template/ucp_pm_message_footer.html',
	'styles/subsilver2/template/ucp_pm_viewfolder.html',
	'styles/subsilver2/template/ucp_pm_viewmessage.html',
	'styles/subsilver2/template/ucp_pm_viewmessage_print.html',
	'styles/subsilver2/template/ucp_profile_avatar.html',
	'styles/subsilver2/template/ucp_profile_signature.html',
	'styles/subsilver2/template/ucp_register.html',
	'styles/subsilver2/template/ucp_zebra_foes.html',
	'styles/subsilver2/template/viewforum_body.html',
	'styles/subsilver2/template/viewtopic_body.html',
	'styles/subsilver2/template/viewtopic_print.html',
	'styles/subsilver2/theme/stylesheet.css',
	'styles/subsilver2/theme/theme.cfg',
	'ucp.php',
	'viewforum.php',
	'viewonline.php',
	'viewtopic.php',
	'web.config',
	'styles/prosilver/theme/images/bg_menu_rtl.gif',
	'styles/prosilver/theme/images/feed.gif',
	'styles/prosilver/theme/images/quote_rtl.gif',
	'styles/subsilver2/imageset/site_logo.gif',
	'styles/subsilver2/imageset/topic_read_hot.gif',
	'styles/subsilver2/imageset/topic_read_hot_mine.gif',
	'styles/subsilver2/imageset/topic_unread_hot.gif',
	'styles/subsilver2/imageset/topic_unread_hot_mine.gif',
	'styles/subsilver2/theme/images/background.gif'),
'binary'		=> array('styles/prosilver/theme/images/bg_menu_rtl.gif',
	'styles/prosilver/theme/images/feed.gif',
	'styles/prosilver/theme/images/quote_rtl.gif',
	'styles/subsilver2/imageset/site_logo.gif',
	'styles/subsilver2/imageset/topic_read_hot.gif',
	'styles/subsilver2/imageset/topic_read_hot_mine.gif',
	'styles/subsilver2/imageset/topic_unread_hot.gif',
	'styles/subsilver2/imageset/topic_unread_hot_mine.gif',
	'styles/subsilver2/theme/images/background.gif'),
);

?>
